@@ -3,15 +3,15 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '1.00';
+our $VERSION = '1.05.1';
 
 =head1 NAME
 
-Finance::Asset
+Finance::Asset - Object representation of a financial asset
 
 =head1 VERSION
 
-1.00
+1.05.1
 
 =head1 SYNOPSYS
 
@@ -61,6 +61,7 @@ sub BUILDARGS {
     my $file = File::ShareDir::dist_file('Finance-Asset', 'underlyings.yml');
     my $assets_ref = LoadFile($file);
     my $params = $assets_ref->{$params_ref->{symbol}};
+    $params->{symbol} = $params_ref->{symbol};
     @$params_ref{keys %$params} = @$params{keys %$params};
 
     if ($params_ref->{exchange_name}) {
@@ -84,13 +85,42 @@ The pip value for a forex asset
 
 has pip_size => (
     is => 'ro',
+    default => 0.0001,
 );
 
-# TODO docs
+=head2 market
+
+The financial market to which this asset belongs
+
+=cut
+
+has market => (
+    is => 'ro',
+    isa => 'Str',
+);
+
+=head2 display_name
+
+User friendly name for the asset
+
+=cut
+
 has display_name => (
     is => 'ro',
+    lazy_build => 1,
 );
 
+sub _build_display_name {
+    my ($self) = @_;
+    return uc $self->symbol;
+}
+
+=head2 exchange_name
+
+Which exchange does the asset belong to. example: FOREX, NASDAQ, etc.
+
+=cut
+
 has _exchange_name => (
     is => 'ro',
 );
@@ -100,13 +130,6 @@ has exchange_name => (
     lazy_build => 1,
 );
 
-=head2 exchange_name
-
-Name of the exchange to which symbol relates. Most are taken from the
-underlyings.yml
-
-=cut
-
 sub _build_exchange_name {
     my $self = shift;
     my $exchange_name = $self->_exchange_name || 'FOREX';
@@ -165,8 +188,14 @@ Value can be one of:
 =cut
 
 has market_convention => (
-    is => 'ro',
-    isa => 'HashRef',
+    is      => 'ro',
+    isa     => 'HashRef',
+    default => sub {
+        return {
+            delta_style            => 'spot_delta',
+            delta_premium_adjusted => 0,
+        };
+    },
 );
 
 =head2 divisor
